@@ -8,9 +8,9 @@ use Mojo::IOLoop;
 use Mojo::MemoryMap;
 use Mojo::Util 'humanize_bytes';
 
-use constant LINUX => $^O eq 'linux';
+use constant MACOS => $^O eq 'darwin';
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 sub register {
   my ($self, $app, $config) = @_;
@@ -189,8 +189,8 @@ sub _resources {
   $self->{map}->writer->change(sub {
     @{$_->{workers}{$$}}{qw(utime stime maxrss)} = (getrusage)[0, 1, 2];
 
-    # On Linux this resturns kilobytes
-    $_->{workers}{$$}{maxrss} = $_->{workers}{$$}{maxrss} * 1000 if LINUX;
+    # macOS actually returns bytes instead of kilobytes
+    $_->{workers}{$$}{maxrss} = $_->{workers}{$$}{maxrss} * 1000 unless MACOS;
 
     for my $id (keys %{$_->{workers}{$$}{connections}}) {
       _read_write($_->{workers}{$$}{connections}{$id}, $id);
